@@ -29,7 +29,6 @@
 // stl
 #include <string>
 
-
 namespace svn
 {
   /**
@@ -39,7 +38,6 @@ namespace svn
   {
   private:
     std::string m_path;
-
     bool m_pathIsUrl;
 
     /**
@@ -79,6 +77,12 @@ namespace svn
      */
     Path& operator= (const Path&);
 
+    /**
+     * Comparison operator
+     */
+    bool
+    operator== (const Path&) const;
+
     /**
      * @return Path string
      */
@@ -117,7 +121,6 @@ namespace svn
     void
     addComponent (const char * component);
 
-
     /**
      * adds a new URL component to the path
      *
@@ -126,7 +129,6 @@ namespace svn
     void
     addComponent (const std::string & component);
 
-
     /**
      * split path in its components
      *
@@ -136,7 +138,6 @@ namespace svn
     void
     split (std::string & dirpath, std::string & basename) const;
 
-
     /**
      * split path in its components including
      * file extension
@@ -148,6 +149,38 @@ namespace svn
     void
     split (std::string & dir, std::string & filename, std::string & ext) const;
 
+    /**
+     * get a basename of a file
+     *
+     * @return basename filename without path
+     */
+    std::string
+    basename () const;
+
+    /**
+     * get a name of directory containing file
+     *
+     * @return dirpath path of directory
+     */
+    std::string
+    dirpath () const;
+
+    /**
+     * get a substring of a path, starting at index
+     *
+     * @param index 
+     * @return substr substring
+     */
+    std::string
+    substr (const size_t index) const;
+
+    /**
+     * return path as a string with unescaped special characters
+     *
+     * @return unescaped path
+     */
+    std::string
+    unescape () const;
 
     /**
      * returns the temporary directory
@@ -155,12 +188,10 @@ namespace svn
     static Path
     getTempDir ();
 
-
     /** return the length of the path-string */
     size_t 
     length () const;
 
-
     /** returns the path with native separators */
     std::string
     native () const;
