@@ -115,7 +115,7 @@ public:
   getPath2 (const svn::Path & path)
   {
     if (diffData.useUrl2)
-      return PathUtf8 (diffData.url1);
+      return PathUtf8 (diffData.url2);
     else
       return path;
   }
@@ -245,12 +245,28 @@ DiffAction::Prepare ()
   if (!Action::Prepare ())
     return false;
 
+  Preferences prefs;
+
+  if (prefs.diffTool.Length () == 0)
+  {
+    TraceError (_("No diff tool set in the preferences"));
+    return false;
+  }
+
   if (m->showDialog)
   {
     // check the first target and try to
     // determine whether we are on a local
     // or remote location
-    svn::Path target = GetTarget ();
+    svn::Path target;
+    if (m->diffData.path.IsEmpty ())
+    {
+      target = GetTarget ();
+    }
+    else
+    {
+      target = PathUtf8 (m->diffData.path);
+    }
     bool isRemote = svn::Url::isValid (target.c_str ());
 
     DiffDlg dlg (GetParent ());
@@ -282,12 +298,20 @@ DiffAction::Prepare ()
 bool
 DiffAction::Perform ()
 {
-  const std::vector<svn::Path> & v = GetTargets ();
-  std::vector<svn::Path>::const_iterator it;
-
-  for (it=v.begin (); it != v.end (); it++)
+  if (m->diffData.path.IsEmpty ())
   {
-    m->diffTarget (*it);
+    const std::vector<svn::Path> & v = GetTargets ();
+    std::vector<svn::Path>::const_iterator it;
+
+    for (it=v.begin (); it != v.end (); it++)
+    {
+      m->diffTarget (*it);
+    }
+  }
+  else
+  {
+    svn::Path target = PathUtf8 (m->diffData.path);
+    m->diffTarget (target);
   }
  
   return true;
