@@ -27,6 +27,7 @@
 #include "wx/wx.h"
 #include "wx/sizer.h"
 #include "wx/valgen.h"
+#include "wx/datectrl.h"
 
 // app
 #include "diff_data.hpp"
@@ -63,6 +64,55 @@ DEFINE_EVENT_TYPE(wxEVENT_UPDATE)
         (wxObject *) NULL \
     ),
 
+
+/**
+ * Tries to interpret @a datestring as a date
+ * (using to current locales) 
+ *
+ * @param datestring string with date (and time)
+ * @param date apr date
+ * @return success?
+ * @retval true valid date
+ */
+static bool
+ParseDateTime (const wxString & datestring, apr_time_t & date)
+{
+  wxString value (datestring);
+
+  TrimString (value);
+
+  if (value.Length () <= 0)
+    return false;
+
+  // parse the string using the current locale setting
+  // (we check only if the complete parsing failed,
+  //  not if only the partial string could be parsed)
+  wxDateTime dateTime;
+  if (0 != dateTime.ParseFormat (datestring, wxT("%Y-%m-%d %H:%M:%S")))
+    return false;
+
+  apr_time_ansi_put (&date, dateTime.GetTicks ());
+  return true;
+}
+
+
+/**
+ * Checks whether the given @a datestring is a valid date/time string
+ * for the current locale
+ *
+ * @retval true valid
+ */
+static bool
+CheckDateTime (const wxString & datestring)
+{
+  apr_time_t time;
+
+  return ParseDateTime (datestring, time);
+}
+
+
+
+
 /**
  * Panel that lets the user select either a revision or a date and
  * optionally another URL (if she doesnt want to compare against
@@ -110,7 +160,7 @@ public:
         valid = CheckRevision (mTextRevision->GetValue ());
     }
     else
-      valid = CheckDateTime (mTextDate->GetValue ());
+      valid = CheckDateTime (mDatePicker->GetValue ().Format (wxT("%Y-%m-%d %H:%M:%S")));
 
     if (valid)
       if (mCheckUseUrl->GetValue ())
@@ -136,8 +186,7 @@ public:
     else
     {
       apr_time_t time=0;
-
-      ParseDateTime (mTextDate->GetValue (), time);
+      apr_time_ansi_put (&time, mDatePicker->GetValue ().GetTicks ());
       svn::DateTime datetime(time);
       return svn::Revision (datetime);
     }
@@ -162,15 +211,16 @@ public:
     if (revision.kind () == svn_opt_revision_date)
     {
       mRadioUseDate->SetValue (true);
-      mTextDate->SetValue (
-        FormatDateTime (revision.date (), wxT("%c")));
+      wxDateTime date;
+      date.ParseDateTime (FormatDateTime (revision.date (),
+        wxT("%Y-%m-%d %H:%M:%S")). c_str ());
+      mDatePicker->SetValue (date);
       mTextRevision->SetValue (wxEmptyString);
       mCheckUseLatest->SetValue (true);
     }
     else
     {
       mRadioUseRevision->SetValue (true);
-      mTextDate->SetValue (wxEmptyString);
 
       if (revision.kind () == svn_opt_revision_head)
       {
@@ -224,7 +274,7 @@ private:
   wxRadioButton * mRadioUseDate;
 
   /** text control with a date */
-  wxTextCtrl * mTextDate;
+  wxDatePickerCtrlBase * mDatePicker;
 
   /** check box: use URL if checked */
   wxCheckBox * mCheckUseUrl;
@@ -249,9 +299,9 @@ private:
     mTextRevision = new wxTextCtrl (this, ID_Revision, wxEmptyString);
     mCheckUseLatest = new wxCheckBox (
       this, ID_UseLatest, _("Use latest"));
-    mCheckUseLatest->SetValue (true);
+    mCheckUseLatest->SetValue (false);
     wxBoxSizer * revisionSizer = new wxBoxSizer (wxHORIZONTAL);
-    revisionSizer->Add (mTextRevision);
+    revisionSizer->Add (mTextRevision, 1, wxEXPAND);
     revisionSizer->Add (mCheckUseLatest, 0, wxLEFT | wxALIGN_CENTER_VERTICAL, 5);
 
     gridSizer->Add (mRadioUseRevision);
@@ -260,10 +310,12 @@ private:
 
     // second row: date
     mRadioUseDate = new wxRadioButton (this, ID_UseDate, _("Date:"));
-    mTextDate = new wxTextCtrl (this, ID_Date, wxEmptyString);
+    mDatePicker = new wxDatePickerCtrl (this, ID_Date, wxDefaultDateTime,
+                                        wxDefaultPosition, wxDefaultSize,
+                                        wxDP_DROPDOWN|wxDP_SHOWCENTURY);
 
     gridSizer->Add (mRadioUseDate);
-    gridSizer->Add (mTextDate);
+    gridSizer->Add (mDatePicker, 0, wxEXPAND);
     gridSizer->Add (0,0);
 
     // third row: url
@@ -309,7 +361,7 @@ private:
   void
   CheckDateCtrls ()
   {
-    mTextDate->Enable (mRadioUseDate->GetValue ());
+    mDatePicker->Enable (mRadioUseDate->GetValue ());
   }
 
   /** checks the url controls for validity */
@@ -340,6 +392,11 @@ private:
   OnCommand (wxCommandEvent & event)
   {
     CheckControls ();
+
+    // forward event
+    wxCommandEvent newEvent (wxEVENT_UPDATE, -1);
+    GetParent ()->ProcessEvent (newEvent);
+
   }
 
 private:
@@ -397,6 +454,7 @@ public:
       _("Diff two revisions/dates");
 
     InitControls ();
+    SetCompareType (DiffData::WITH_DIFFERENT_REVISION);
     CheckControls ();
   }
 
@@ -406,6 +464,17 @@ public:
     DiffData diffData;
     diffData.compareType = GetCompareType ();
 
+    if (mRevisionOne->GetUseUrl ())
+    {
+      diffData.useUrl1 = true;
+      diffData.url1 = mRevisionOne->GetUrl ();
+    }
+    if (mRevisionTwo->GetUseUrl ())
+    {
+      diffData.useUrl2 = true;
+      diffData.url2 = mRevisionTwo->GetUrl ();
+    }
+		
     switch (diffData.compareType)
     {
     case DiffData::WITH_DIFFERENT_REVISION:
@@ -463,7 +532,13 @@ public:
       AddCompareType (types [i]);
 
     // try to set old selection
-    SetCompareType (oldCompareType);
+    bool returnValue = SetCompareType (oldCompareType);
+    if (!returnValue)
+    {
+      mCompareType = 0;
+      SetCompareType (types[0]);
+      CheckControls ();
+    }
   }
 
   void
@@ -503,8 +578,8 @@ private:
         COMPARE_COUNT, mCompareTypeLabels, 
         wxCB_READONLY);
 
-      typeSizer->Add (label);
-      typeSizer->Add (mComboCmpType, 0, wxEXPAND);
+      typeSizer->Add (label, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL);
+      typeSizer->Add (mComboCmpType, 1, wxEXPAND);
     }
 
     // second row: first revision/url
@@ -542,8 +617,8 @@ private:
 
     AllowCompareTypes ();
     // call this after AllowCompareTypes (), because ComboCmpType is not initialized yet.
-    // Set CompareType to BASE by default.
-    mCompareType = 0;
+    // Set CompareType to "Diff to another rev/date" by default.
+    mCompareType = 2;
   }
 
   void
@@ -671,6 +746,12 @@ private:
     CheckControls ();
   }
 
+  void
+  OnUpdate (wxCommandEvent & event)
+  {
+    CheckControls ();
+  }
+
 private:
   DECLARE_EVENT_TABLE ()
 };
@@ -678,7 +759,7 @@ private:
 
 BEGIN_EVENT_TABLE (DiffDlg::Data, wxPanel)
   EVT_COMBOBOX (ID_CompareType, Data::OnCommand)
-  EVENT_UPDATE (-1, Data::OnCommand)
+  EVENT_UPDATE (-1, Data::OnUpdate)
 END_EVENT_TABLE ()
 
 DiffDlg::DiffDlg (wxWindow * parent)
@@ -689,7 +770,7 @@ DiffDlg::DiffDlg (wxWindow * parent)
 
   // Add all sizers to main sizer
   wxBoxSizer *mainSizer = new wxBoxSizer (wxVERTICAL);
-  mainSizer->Add (m, 0, wxALL, 5);
+  mainSizer->Add (m, 1, wxEXPAND|wxALL, 5);
 
   SetAutoLayout(true);
   SetSizer(mainSizer);
