@@ -32,19 +32,20 @@
 
 // app
 #include "external_program_action.hpp"
+#include "action_event.hpp"
+#include "ids.hpp"
 #include "preferences.hpp"
 #include "utils.hpp"
 #include "verblist.hpp"
 
-
 ExternalProgramAction::ExternalProgramAction (
   wxWindow * parent, long verb_id, bool treat_as_folder) 
  : Action (parent, _("Execute"), GetBaseFlags ()), 
-   m_verb_id (verb_id), m_treat_as_folder (treat_as_folder)
+   m_verb_id (verb_id), m_treat_as_folder (treat_as_folder),
+   m_parent (parent)
 {
 }
 
-
 bool
 ExternalProgramAction::Prepare ()
 {
@@ -55,7 +56,7 @@ bool
 ExternalProgramAction::Perform ()
 {
   VerbList verb_list;
-  wxBusyCursor busy_cursor;
+//  wxBusyCursor busy_cursor;
 
   // The actual target
   svn::Path path = GetTarget ();
@@ -104,7 +105,13 @@ ExternalProgramAction::Perform ()
       else
         args.Replace (wxT("%1"), target_document, true);
     
-      wxExecute (prefs.explorer + wxT(" ") + args);
+      wxString cmd (prefs.explorer + wxT(" ") + args);
+
+      wxString msg;
+      msg.Printf (_("Execute file explorer: %s"), cmd.c_str ());
+      Trace (msg);
+
+      ActionEvent::Post (m_parent, TOKEN_CMD, cmd);
     }
   }
   else
@@ -124,7 +131,13 @@ ExternalProgramAction::Perform ()
       else
         args.Replace (wxT("%1"), target_document, true);
    
-      wxExecute (prefs.editor + wxT(" ") + args);
+      wxString cmd (prefs.editor + wxT(" ") + args);
+
+      wxString msg;
+      msg.Printf (_("Execute editor: %s"), cmd.c_str ());
+      Trace (msg);
+
+      ActionEvent::Post (m_parent, TOKEN_CMD, cmd);
     }
   }
 
