@@ -28,19 +28,19 @@
 // wxWidgets
 #include "wx/wx.h"
 // apr
-//#include "apr_time.h"
+#include "apr_time.h"
 
 // svncpp
 #include "svncpp/client.hpp"
 #include "svncpp/exception.hpp"
 #include "svncpp/path.hpp"
 #include "svncpp/status.hpp"
+#include "svncpp/url.hpp"
 
 // app
 #include "file_info.hpp"
 #include "utils.hpp"
 
-
 static void
 info_print_time (apr_time_t atime, const wxChar * desc, wxString & str)
 {
@@ -65,7 +65,6 @@ struct FileInfo::Data
   wxString info;
   bool withUpdate;
 
-
   Data (svn::Context * ctx, bool update)
     : context (ctx), withUpdate (update)
   {
@@ -78,7 +77,6 @@ struct FileInfo::Data
     info += wxT("\n");
   }
 
-
   void
   addInfoForStatus (const svn::Status & status)
   {
@@ -94,20 +92,18 @@ struct FileInfo::Data
     svn_boolean_t text_conflict = FALSE;
     svn_boolean_t props_conflict = FALSE;
 
-    tmp = Utf8ToLocal (entry.name ());
-    str.Printf (_("Name: %s"), tmp.c_str ());
+    str.Printf (_("Name: %s"), Utf8ToLocal (svn::Url::unescape (entry.name ())).c_str ());
     addLine (str);
 
-    tmp = Utf8ToLocal (entry.url ());
-    str.Printf (_("URL: %s"), tmp.c_str ());
+    str.Printf (_("URL: %s"), Utf8ToLocal (svn::Url::unescape (entry.url ())).c_str ());
     addLine (str);
 
-    if (entry.repos ()) {
-      tmp = Utf8ToLocal (entry.repos ());
-    } else {
+    if (entry.repos ())
+      tmp = Utf8ToLocal (svn::Url::unescape (entry.repos ()));
+    else
       tmp = _("<None>");
-    }
-    str.Printf (_("Repository: %s"),  tmp.c_str ());
+
+    str.Printf (_("Repository: %s"), tmp.c_str ());
     addLine (str);
 
     if (entry.uuid ()) {
@@ -303,7 +299,7 @@ FileInfo::info () const
   {
     svn::Path path = *it;
 
-    m->createInfoForPath (client, path.c_str ());
+    m->createInfoForPath (client, path.unescape ().c_str ());
     m->addLine ();
   }
 
