@@ -49,17 +49,17 @@
 #include "rapidsvn_frame.hpp"
 
 // bitmaps
-#include "res/bitmaps/computer.xpm"
-#include "res/bitmaps/versioned_folder.xpm"
-#include "res/bitmaps/open_folder.xpm"
-#include "res/bitmaps/folder.xpm"
-#include "res/bitmaps/nonsvn_open_folder.xpm"
-#include "res/bitmaps/earth.xpm"
-#include "res/bitmaps/modified_versioned_folder.xpm"
-#include "res/bitmaps/modified_open_folder.xpm"
-#include "res/bitmaps/bookmark.xpm"
-#include "res/bitmaps/externals_folder.xpm"
-#include "res/bitmaps/open_externals_folder.xpm"
+#include "res/bitmaps/computer.png.h"
+#include "res/bitmaps/folder.png.h"
+#include "res/bitmaps/open_folder.png.h"
+#include "res/bitmaps/nonsvn_folder.png.h"
+#include "res/bitmaps/nonsvn_open_folder.png.h"
+#include "res/bitmaps/modified_folder.png.h"
+#include "res/bitmaps/modified_open_folder.png.h"
+#include "res/bitmaps/bookmark.png.h"
+#include "res/bitmaps/externals_folder.png.h"
+#include "res/bitmaps/externals_open_folder.png.h"
+#include "res/bitmaps/repository_bookmark.png.h"
 
 enum
 {
@@ -68,10 +68,10 @@ enum
   FOLDER_IMAGE_OPEN_FOLDER,
   FOLDER_IMAGE_NONSVN_FOLDER,
   FOLDER_IMAGE_NONSVN_OPEN_FOLDER,
-  FOLDER_IMAGE_EARTH,
   FOLDER_IMAGE_MODIFIED_FOLDER,
   FOLDER_IMAGE_MODIFIED_OPEN_FOLDER,
   FOLDER_IMAGE_BOOKMARK,
+  FOLDER_IMAGE_REPOSITORY_BOOKMARK,
   FOLDER_IMAGE_EXTERNALS_FOLDER,
   FOLDER_IMAGE_OPEN_EXTERNALS_FOLDER,
   FOLDER_IMAGE_COUNT
@@ -152,17 +152,17 @@ public:
     : singleContext (0), window (window), listener (0), useAuthCache (true)
   {
     imageList = new wxImageList (16, 16, TRUE);
-    imageList->Add (wxIcon (computer_xpm));
-    imageList->Add (wxIcon (versioned_folder_xpm));
-    imageList->Add (wxIcon (open_folder_xpm));
-    imageList->Add (wxIcon (folder_xpm));
-    imageList->Add (wxIcon (nonsvn_open_folder_xpm));
-    imageList->Add (wxIcon (earth_xpm));
-    imageList->Add (wxIcon (modified_versioned_folder_xpm));
-    imageList->Add (wxIcon (modified_open_folder_xpm));
-    imageList->Add (wxIcon (bookmark_xpm));
-    imageList->Add (wxIcon (externals_folder_xpm));
-    imageList->Add (wxIcon (open_externals_folder_xpm));
+    imageList->Add (EMBEDDED_BITMAP(computer_png));
+    imageList->Add (EMBEDDED_BITMAP(folder_png));
+    imageList->Add (EMBEDDED_BITMAP(open_folder_png));
+    imageList->Add (EMBEDDED_BITMAP(nonsvn_folder_png));
+    imageList->Add (EMBEDDED_BITMAP(nonsvn_open_folder_png));
+    imageList->Add (EMBEDDED_BITMAP(modified_folder_png));
+    imageList->Add (EMBEDDED_BITMAP(modified_open_folder_png));
+    imageList->Add (EMBEDDED_BITMAP(bookmark_png));
+    imageList->Add (EMBEDDED_BITMAP(repository_bookmark_png));
+    imageList->Add (EMBEDDED_BITMAP(externals_folder_png));
+    imageList->Add (EMBEDDED_BITMAP(externals_open_folder_png));
 
     treeCtrl = new wxTreeCtrl (window, -1, pos, size,
                                wxTR_HAS_BUTTONS|wxTR_SINGLE);
@@ -435,15 +435,20 @@ public:
         for (; it!= bookmarks.end (); it++)
         {
           const wxString & path = it->first;
+          svn::Path pathUtf8 (PathUtf8 (path));
+          int image;
+
+          if (pathUtf8.isUrl ())
+            image = FOLDER_IMAGE_REPOSITORY_BOOKMARK;
+          else
+            image = FOLDER_IMAGE_BOOKMARK;
 
           FolderItemData* data= new FolderItemData (FOLDER_TYPE_BOOKMARK,
                                                     path, path, TRUE);
           wxTreeItemId newId = treeCtrl->AppendItem (parentId, path,
-                                                     FOLDER_IMAGE_BOOKMARK,
-                                                     FOLDER_IMAGE_BOOKMARK,
-                                                     data);
+                                                     image, image, data);
           treeCtrl->SetItemHasChildren (newId, TRUE);
-          treeCtrl->SetItemImage (newId, FOLDER_IMAGE_BOOKMARK,
+          treeCtrl->SetItemImage (newId, image,
                                   wxTreeItemIcon_Expanded);
         }
       }
@@ -516,8 +521,8 @@ public:
       svn::Status& status = *it;
 
       // Convert path from UTF8 to Local
-      wxFileName filename (Utf8ToFileName (status.path ()));
-      wxString path (filename.GetFullPath ());
+      svn::Path filename (status.path ());
+      wxString path (Utf8ToLocal (filename.native ()));
 
       // Only display versioned directories and exclude parent itself
       if (((status.entry ().kind () == svn_node_dir) ||
@@ -545,14 +550,15 @@ public:
           image = FOLDER_IMAGE_MODIFIED_FOLDER;
           open_image = FOLDER_IMAGE_MODIFIED_OPEN_FOLDER;
         }
-
-        wxFileName filename (path);
         FolderItemData * data = new FolderItemData (
           FOLDER_TYPE_NORMAL, path, 
-          filename.GetFullName (), TRUE);
+          Utf8ToLocal (filename.basename ()), 
+          TRUE);
 
         wxTreeItemId newId = treeCtrl->AppendItem(
-          parentId, filename.GetFullName (), image, image, data);
+          parentId, 
+          Utf8ToLocal (filename.basename ()), 
+          image, image, data);
 
         treeCtrl->SetItemHasChildren (newId, HasSubdirectories (path));
         treeCtrl->SetItemImage (newId, open_image, wxTreeItemIcon_Expanded);
@@ -571,7 +577,7 @@ public:
       client.ls (parentPathUtf8.c_str (), rev, false);
     svn::DirEntries::const_iterator it;
 
-    //bool parentHasSubdirectories = false;
+    bool parentHasSubdirectories = false;
     for (it = entries.begin (); it != entries.end (); it++)
     {
       svn::DirEntry entry = *it;
@@ -583,11 +589,12 @@ public:
       if (parentPath.Last () == '/')
         offset = 0;
       wxString filename (fullPath.Mid (parentPath.length () + offset));
-      //parentHasSubdirectories = true;
 
       if (entry.kind () != svn_node_dir)
         continue;
 
+      parentHasSubdirectories = true;
+
       FolderItemData * data =
         new FolderItemData (FOLDER_TYPE_NORMAL,
                             fullPath,
@@ -600,7 +607,10 @@ public:
       treeCtrl->SetItemImage (newId, open_image,
                               wxTreeItemIcon_Expanded);
     }
-  }
+
+    // Remove the "expansion" image from the folder if is has no children
+    if (!parentHasSubdirectories)
+      treeCtrl->SetItemHasChildren (parentId, FALSE);  }
 
   /**
    * Finds the child entry with @a path
@@ -622,23 +632,22 @@ public:
       if (!data->isReal ())
         break;
 
-      const svn::Path nodePath (LocalToUtf8 (data->getPath ()));
+      const wxString nodePath (data->getPath ());
       if (nodePath.length () == 0)
         break;
 
       // first check: full match?
-      if (path.IsSameAs (Utf8ToLocal (nodePath.c_str ())))
+      if (path == nodePath)
       {
         childId = id;
         break;
       }
 
       // second check: match until path delimiter
-      wxString prefix (path.Left (Utf8ToLocal (nodePath.c_str()).length ()));
-      wxString sep (path.Mid (Utf8ToLocal (nodePath.c_str()).length (), 1));
+      wxString prefix (path.Left (nodePath.length ()));
+      wxString sep (path.Mid (nodePath.length (), 1));
 
-      if (prefix.IsSameAs (Utf8ToLocal (nodePath.c_str ())) &&
-          IsValidSeparator (sep))
+      if ((prefix == nodePath) && IsValidSeparator (sep))
       {
         childId = id;
         break;
@@ -698,24 +707,23 @@ public:
       if (!data->isReal ())
 			  break;
 
-      const svn::Path nodePath (LocalToUtf8 (data->getPath ()));
+      const wxString nodePath (data->getPath ());
       if (nodePath.length () == 0)
 				break;
 
       // check if @a path and @a nodePath match already
       // in this case we are done
-      if (pathP.IsSameAs (Utf8ToLocal (nodePath.c_str())))
+      if (pathP == nodePath)
       {
         success = true;
         break;
 
       }
 
-      wxString prefix (pathP.Left (Utf8ToLocal (nodePath.c_str ()).length()));
-      wxString sep (pathP.Mid (Utf8ToLocal (nodePath.c_str ()).length(), 1));
+      wxString prefix (pathP.Left (nodePath.length()));
+      wxString sep (pathP.Mid (nodePath.length(), 1));
 
-      if ((!prefix.IsSameAs
-          (Utf8ToLocal (nodePath.c_str()))) || !IsValidSeparator (sep))
+      if ((prefix != nodePath) || !IsValidSeparator (sep))
        break;
 
       if (!data->hasChildren ())
@@ -924,7 +932,7 @@ FolderBrowser::~FolderBrowser ()
 }
 
 void
-FolderBrowser::Refresh ()
+FolderBrowser::RefreshFolderBrowser ()
 {
   // remember selected
   wxString bookmarkPath = m->GetSelectedBookmarkPath ();
