@@ -87,6 +87,7 @@ enum
   ID_Update,
   ID_Unlock,
   ID_Edit,
+  ID_Annotate,
   ID_File_Max,
 
   // Reserve space for 16 file verbs (I've never seen any files with more)
@@ -172,9 +173,17 @@ enum
   TOKEN_DELETE_ACTION,
   TOKEN_UPDATE_SORTING,
   TOKEN_UPDATE_ASCENDING,
+  TOKEN_ANNOTATE,
+  TOKEN_LOG,
 
+  LISTENER_MIN,
   SIG_GET_LOG_MSG,
   SIG_GET_LOGIN,
+  SIG_SSL_SERVER_TRUST_PROMPT,
+  SIG_SSL_CLIENT_CERT_PROMPT,
+  SIG_SSL_CLIENT_CERT_PW_PROMPT,
+  LISTENER_MAX,
+
 
   FILELIST_CTRL,
   FOLDER_BROWSER
