@@ -92,12 +92,20 @@ private:
    */
   void OnDiff (wxCommandEvent & event);
 
+
   /**
    * Event handler for the "Merge" button
    * @param event
    */
   void OnMerge (wxCommandEvent & event);
 
+
+  /**
+   * Event handler for the "Annotate" button
+   * @param event
+   */
+  void OnAnnotate (wxCommandEvent & event);
+
   DECLARE_EVENT_TABLE ()
 };
 
