@@ -72,11 +72,11 @@ MoveAction::Prepare ()
 }
 
 bool
-MoveAction::Perform ()
+MoveAction::Perform ()  
 {
   svn::Client client (GetContext ());
-
-  svn::Path destPath (PathUtf8 (m_destination));
+  svn::Path destPath (GetPath().path());
+  destPath.addComponent(LocalToUtf8 (m_destination));
   svn::Revision unusedRevision;
   std::vector<svn::Path> targets (GetTargets ().targets ());
   std::vector<svn::Path>::iterator it;
