@@ -33,9 +33,8 @@
 
 enum
 {
-  MOVE_MOVE,
-  MOVE_COPY,
-  MOVE_RENAME
+  MOVE_MOVE = 0,
+  MOVE_COPY
 };
 
 /**
@@ -44,17 +43,12 @@ enum
  */
 class MoveAction:public Action
 {
-private:
-  int m_kind;
-  wxString m_destination;
-  bool m_force;
-
 public:
   /**
    * constructor
    *
    * @param parent parent window
-   * @param type kind of action (MOVE_MOVE, MOVE_COPY, MOVE_RENAME)
+   * @param type kind of action (MOVE_MOVE, MOVE_COPY)
    */
   MoveAction (wxWindow * parent, int kind);
 
@@ -66,8 +60,13 @@ public:
    */
   static unsigned int GetBaseFlags ()
   {
-    return SINGLE_TARGET|RESPOSITORY_TYPE|VERSIONED_WC_TYPE;
+    return SINGLE_TARGET|MULTIPLE_TARGETS|RESPOSITORY_TYPE|VERSIONED_WC_TYPE;
   }
+
+private:
+  int m_kind;
+  wxString m_destination;
+  bool m_force;
 };
 
 #endif
