@@ -1,9 +1,21 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2004 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
  *
- * This software is licensed as described in the file LICENSE.txt,
- * which you should have received as part of this distribution.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in the file GPL.txt); if not, write to 
+ * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Boston, MA  02110-1301  USA
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -47,6 +59,8 @@ static const wxChar CONF_PURGE_TEMP_FILES[] =
   wxT("/Preferences/PurgeTempFiles");
 static const wxChar CONF_AUTH_PER_BOOKMARK[] =
   wxT("/Preferences/AuthPerBookmark");
+static const wxChar CONF_USE_AUTH_CACHE[] =
+  wxT("/Preferences/UseAuthCache");
 static const wxChar CONF_DIFF_TOOL[] =
   wxT("/Preferences/DiffTool");
 static const wxChar CONF_DIFF_TOOL_ARGS[] =
@@ -57,7 +71,7 @@ Preferences::Preferences ()
     explorer (DEFAULT_EXPLORER), explorerAlways (false),
     explorerArgs (wxEmptyString), diffTool (DEFAULT_DIFF_TOOL),
     diffToolArgs (wxEmptyString), purgeTempFiles (true),
-    authPerBookmark (false)
+    authPerBookmark (false), useAuthCache (true)
 {
   Read ();
 }
@@ -84,9 +98,9 @@ Preferences::Read ()
   diffTool = config->Read (CONF_DIFF_TOOL, diffTool);
   diffToolArgs = config->Read (CONF_DIFF_TOOL_ARGS, diffToolArgs);
 
-  config->Read (CONF_PURGE_TEMP_FILES, &purgeTempFiles);
-
+  config->Read (CONF_PURGE_TEMP_FILES,  &purgeTempFiles);
   config->Read (CONF_AUTH_PER_BOOKMARK, &authPerBookmark);
+  config->Read (CONF_USE_AUTH_CACHE,    &useAuthCache);
 }
 
 void Preferences::Write () const
@@ -107,6 +121,7 @@ void Preferences::Write () const
   config->Write (CONF_PURGE_TEMP_FILES, purgeTempFiles);
 
   config->Write (CONF_AUTH_PER_BOOKMARK, authPerBookmark);
+  config->Write (CONF_USE_AUTH_CACHE, useAuthCache);
 }
 
 /* -----------------------------------------------------------------
