@@ -29,18 +29,13 @@
 #include "wx/frame.h"
 #include "wx/textctrl.h"
 #include "wx/toolbar.h"
-#include "wx/splitter.h"
 
 // app
 #include "action_worker.hpp"
 #include "tracer.hpp"
 #include "log_action.hpp"
-#include "filelist_ctrl.hpp"
-#include "folder_browser.hpp"
 #include "utils.hpp"
 
-#define SPLITTER_WINDOW   100
-
 typedef enum
 {
   ACTIVEPANE_FOLDER_BROWSER,
@@ -53,6 +48,7 @@ class svn::Targets;
 class wxFrame;
 class wxMenu;
 class wxString;
+class wxListEvent;
 
 class RapidSvnFrame : public wxFrame
 {
@@ -135,6 +131,7 @@ private:
 
   // Events from action threads
   void OnActionEvent (wxCommandEvent & event);
+  void OnListenerEvent (wxCommandEvent & event);
 
   // Folder Browser
   void AddWcBookmark ();
@@ -147,10 +144,6 @@ private:
   void OnLogin (wxCommandEvent & event);
   void OnLogout (wxCommandEvent & event);
 
-  // Help listener to handle callbacks
-  void OnGetLogMessage (wxCommandEvent & event);
-  void OnGetLogin (wxCommandEvent & event);
-
   /**
    * Invoke the default action on the currently selected item(s)
    *
@@ -161,11 +154,15 @@ private:
    */
   bool InvokeDefaultAction ();
 
-  /** update the contents of the filelist */
-  void UpdateFileList ();
+  /** 
+   * Update the contents of the filelist 
+   */
+  void RefreshFileList ();
 
-  /** update the contents of the folder browser */
-  void UpdateFolderBrowser ();
+  /** 
+   * Update the contents of the folder browser 
+   */
+  void RefreshFolderBrowser ();
 
   // Auxiliary functions
   void UpdateCurrentPath ();
@@ -173,6 +170,7 @@ private:
   void UpdateMenuIncludePath ();
   void UpdateMenuAscending ();
   void SetIncludePathVisibility (bool flatMode);
+  void OnSize (wxSizeEvent & sizeEvent);
 
   // Enable/disable action menu items
   bool ValidateIDActionFlags (int id, unsigned int selectionActionFlags);
@@ -203,11 +201,6 @@ private:
   void Contents ();
   void ShowPreferences ();
 
-  FolderBrowser *GetFolderBrowser ()
-  {
-    return m_folder_browser;
-  }
-
   void Perform (Action * action);
 
 private:
@@ -217,40 +210,14 @@ private:
 
   ActionWorker * m_actionWorker;
 
-  FolderBrowser * m_folder_browser;
-  FileListCtrl *m_listCtrl;
-
-  wxSplitterWindow *m_horiz_splitter;
-  wxSplitterWindow *m_vert_splitter;
-
   wxPanel *m_info_panel;
 
-  wxTextCtrl *m_log;
-  EventTracer *m_logTracer;
-
   size_t m_toolbar_rows;        // 1 or 2 only (toolbar rows)
 
-  wxString m_currentPath;
   wxString m_title;
   svn::Context * m_context;
   ActivePane m_activePane;
 
-  /**
-   * add message to log window
-   *
-   * @param msg message to show
-   */
-  void
-  Trace (const wxString & msg) ;
-
-  /**
-   * add error message to log window marked red
-   *
-   * @param msg error message to show
-   */
-  void
-  TraceError (const wxString & msg) ;
-
 private:
   DECLARE_EVENT_TABLE ()
 };
