@@ -26,9 +26,6 @@
 #pragma warning( disable: 4786 )// debug symbol truncated
 #endif
 
-// stl
-#include <string>
-
 // subversion api
 #include "svn_client.h"
 
@@ -422,10 +419,12 @@ namespace svn
                  const char * message) throw (ClientException)
   {
     Pool pool;
-    m_context->setLogMessage (message);
-
     Targets targets (path.c_str ());
 
+    // Do not use setting the message, because it must be done by callback.
+    // Preserving "message" parameter for compatibility
+//    m_context->setLogMessage (message);
+
     svn_client_commit_info_t *commit_info = NULL;
     svn_error_t * error =  
       svn_client_mkdir (&commit_info, 
@@ -442,7 +441,10 @@ namespace svn
                  const char * message) throw (ClientException)
   {
     Pool pool;
-    m_context->setLogMessage (message);
+
+    // Do not use setting the message, because it must be done by callback.
+    // Preserving "message" parameter for compatibility
+//    m_context->setLogMessage (message);
 
     svn_client_commit_info_t *commit_info = NULL;
     svn_error_t * error =  
