@@ -1,9 +1,21 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2004 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
  *
- * This software is licensed as described in the file LICENSE.txt,
- * which you should have received as part of this distribution.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library (in the file LGPL.txt); if not, 
+ * write to the Free Software Foundation, Inc., 51 Franklin St, 
+ * Fifth Floor, Boston, MA  02110-1301  USA
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -16,7 +28,6 @@
 
 // subversion api
 #include "svn_client.h"
-//#include "svn_utf.h"
 
 // svncpp
 #include "svncpp/client.hpp"
@@ -24,12 +35,10 @@
 #include "svncpp/exception.hpp"
 #include "svncpp/pool.hpp"
 #include "svncpp/revision.hpp"
-
+#include "m_check.hpp"
 
 namespace svn
 {
-
-
   /**
    * lists properties in @a path no matter whether local or
    * repository
@@ -40,13 +49,13 @@ namespace svn
    * @return PropertiesList
    */
   PathPropertiesMapList
-  Client::proplist(const Path &path,
-                   const Revision &revision,
-                   bool recurse)
+  Client::proplist (const Path & path,
+                    const Revision & revision,
+                    bool recurse)
   {
     Pool pool;
-
     apr_array_header_t * props;
+
     svn_error_t * error =
       svn_client_proplist (&props,
                            path.c_str (), 
@@ -54,7 +63,7 @@ namespace svn
                            recurse,
                            *m_context,
                            pool);
-    if(error != NULL)
+    if (error != NULL)
     {
       throw ClientException (error);
     }
@@ -65,11 +74,6 @@ namespace svn
       svn_client_proplist_item_t *item = 
         ((svn_client_proplist_item_t **)props->elts)[j];
 
-/*      const char *node_name_native;
-      svn_utf_cstring_from_utf8_stringbuf (&node_name_native,
-                                           item->node_name,
-                                           pool );*/
-
       PropertiesMap prop_map;
 
       apr_hash_index_t *hi;
@@ -77,18 +81,15 @@ namespace svn
            hi = apr_hash_next (hi))
       {
         const void *key;
-//        const char *key_native;
         void *val;
 
         apr_hash_this (hi, &key, NULL, &val);
-/*        svn_utf_cstring_from_utf8 (&key_native, (char *)key, pool);
-        const svn_string_t *propval = (const svn_string_t *)val;
-        svn_utf_string_from_utf8 (&propval, propval, pool); */
 
-        prop_map[ std::string( (const char *)key ) ] = std::string( ((const svn_string_t *)val)->data );
+        prop_map [std::string ((const char *)key)] = 
+          std::string (((const svn_string_t *)val)->data);
       }
 
-      path_prop_map_list.push_back( PathPropertiesMapEntry( item->node_name->data, prop_map ) );
+      path_prop_map_list.push_back (PathPropertiesMapEntry (item->node_name->data, prop_map));
     }
 
     return path_prop_map_list;
@@ -105,23 +106,23 @@ namespace svn
    */
   
   PathPropertiesMapList
-  Client::propget(const char *propName,
-                  const Path &path,
-                  const Revision &revision,
-                  bool recurse)
+  Client::propget (const char *propName,
+                   const Path &path,
+                   const Revision &revision,
+                   bool recurse)
   {
     Pool pool;
 
     apr_hash_t *props;
     svn_error_t * error =
       svn_client_propget (&props,
-                           propName,
-                           path.c_str (), 
-                           revision.revision (),
-                           recurse,
-                           *m_context,
-                           pool);
-    if(error != NULL)
+                          propName,
+                          path.c_str (), 
+                          revision.revision (),
+                          recurse,
+                          *m_context,
+                          pool);
+    if (error != NULL)
     {
       throw ClientException (error);
     }
@@ -136,18 +137,13 @@ namespace svn
       PropertiesMap prop_map;
 
       const void *key;
-//      const char *key_native;
       void *val;
 
       apr_hash_this (hi, &key, NULL, &val);
-/*      svn_utf_cstring_from_utf8 (&key_native, (char *)key, pool);
-      const svn_string_t *propval = (const svn_string_t *)val;
-      svn_utf_string_from_utf8 (&propval, propval, pool); */
 
-//        prop_map[ std::string( (const char *)key ) ] = std::string( ((const svn_string_t *)val)->data );
-      prop_map[ std::string( propName ) ] = std::string( ((const svn_string_t *)val)->data );
+      prop_map [std::string (propName)] = std::string (((const svn_string_t *)val)->data);
 
-      path_prop_map_list.push_back( PathPropertiesMapEntry( (const char *)key, prop_map ) );
+      path_prop_map_list.push_back (PathPropertiesMapEntry ((const char *)key, prop_map));
     }
 
     return path_prop_map_list;
@@ -164,26 +160,55 @@ namespace svn
    * @param recurse
    * @return PropertiesList
    */
+#if CHECK_SVN_VERSION(1,2)
   void
-  Client::propset(const char *propName,
-                  const char *propValue,
-                  const Path &path,
-                  const Revision &revision,
-                  bool recurse)
-    {
-      Pool pool;
-      const svn_string_t * propval 
-        = svn_string_create ((const char *) propValue, pool);
+  Client::propset (const char * propName,
+                   const char * propValue,
+                   const Path & path,
+                   const Revision & revision,
+                   bool recurse,
+                   bool skip_checks)
+  {
+    Pool pool;
 
-//      const char *pname_utf8;
-  //    svn_utf_cstring_to_utf8 (&pname_utf8, propName, pool);
+    const svn_string_t * propval =
+      svn_string_create ((const char *) propValue, pool);
 
-      svn_error_t * error = 
-        svn_client_propset (propName, propval, path.c_str (),
-                            recurse, pool);
-      if(error != NULL)
-        throw ClientException (error);
-    }
+    svn_error_t * error = 
+      svn_client_propset2 (propName,
+                           propval,
+                           path.c_str (),
+                           recurse,
+                           skip_checks,
+                           *m_context,
+                           pool);
+    if (error != NULL)
+      throw ClientException (error);
+  }
+#else
+  void
+  Client::propset (const char * propName,
+                   const char * propValue,
+                   const Path & path,
+                   const Revision & revision,
+                   bool recurse,
+                   bool skip_checks)
+  {
+    Pool pool;
+
+    const svn_string_t * propval =
+      svn_string_create ((const char *) propValue, pool);
+
+    svn_error_t * error = 
+      svn_client_propset (propName,
+                          propval,
+                          path.c_str (),
+                          recurse,
+                          pool);
+    if (error != NULL)
+      throw ClientException (error);
+  }
+#endif
 
   /**
    * delete property in @a path no matter whether local or
@@ -197,23 +222,20 @@ namespace svn
    * @return PropertiesList
    */
   void
-  Client::propdel(const char *propName,
-                  const Path &path,
-                  const Revision &revision,
-                  bool recurse)
+  Client::propdel (const char *propName,
+                   const Path &path,
+                   const Revision &revision,
+                   bool recurse)
   {
     Pool pool;
 
-//    const char *pname_utf8;
-  //  svn_utf_cstring_to_utf8 (&pname_utf8, propName, pool);
-
     svn_error_t * error = 
-      error = svn_client_propset (propName, 
-                                  NULL, // value = NULL
-                                  path.c_str (),
-                                  recurse,
-                                  pool);
-    if(error != NULL)
+      svn_client_propset (propName, 
+                          NULL, // value = NULL
+                          path.c_str (),
+                          recurse,
+                          pool);
+    if (error != NULL)
       throw ClientException (error);
   }
   
@@ -232,8 +254,8 @@ namespace svn
    * @return PropertiesList
    */
   std::pair<svn_revnum_t,PropertiesMap>
-  Client::revproplist(const Path &path,
-                      const Revision &revision)
+  Client::revproplist (const Path &path,
+                       const Revision &revision)
   {
     Pool pool;
 
@@ -258,19 +280,15 @@ namespace svn
          hi = apr_hash_next (hi))
     {
       const void *key;
-//      const char *key_native;
       void *val;
 
       apr_hash_this (hi, &key, NULL, &val);
-/*      svn_utf_cstring_from_utf8 (&key_native, (char *)key, pool);
-      const svn_string_t *propval = (const svn_string_t *)val;
-      svn_utf_string_from_utf8 (&propval, propval, pool); */
 
-      prop_map[ std::string( (const char *)key ) ] = std::string( ((const svn_string_t *)val)->data );
-//      prop_map[ std::string( key_native ) ] = std::string( propval->data );
+      prop_map [std::string ((const char *)key)] = 
+        std::string (((const svn_string_t *)val)->data);
     }
 
-    return std::pair<svn_revnum_t,PropertiesMap>( revnum, prop_map );
+    return std::pair<svn_revnum_t,PropertiesMap> (revnum, prop_map);
   }
 
   /**
@@ -284,9 +302,9 @@ namespace svn
    */
   
   std::pair<svn_revnum_t,std::string>
-  Client::revpropget(const char *propName,
-                     const Path &path,
-                     const Revision &revision)
+  Client::revpropget (const char *propName,
+                      const Path &path,
+                      const Revision &revision)
   {
     Pool pool;
 
@@ -300,19 +318,16 @@ namespace svn
                               &revnum,
                               *m_context,
                               pool);
-    if(error != NULL)
+    if (error != NULL)
     {
       throw ClientException (error);
     }
 
     // if the property does not exist NULL is returned
-    if( propval == NULL )
-      return std::pair<svn_revnum_t,std::string>( 0, std::string() );
+    if (propval == NULL)
+      return std::pair<svn_revnum_t,std::string> (0, std::string());
 
-/*    const svn_string_t *propval_str;
-    svn_utf_string_from_utf8 (&propval_str, propval, pool); */
-
-    return std::pair<svn_revnum_t,std::string>( revnum, std::string (propval->data) );
+    return std::pair<svn_revnum_t,std::string> (revnum, std::string (propval->data));
   }
 
   /**
@@ -328,20 +343,17 @@ namespace svn
    * @return PropertiesList
    */
   svn_revnum_t
-  Client::revpropset(const char *propName,
-                     const char *propValue,
-                     const Path &path,
-                     const Revision &revision,
-                     bool force)
+  Client::revpropset (const char *propName,
+                      const char *propValue,
+                      const Path &path,
+                      const Revision &revision,
+                      bool force)
   {
     Pool pool;
 
     const svn_string_t * propval 
       = svn_string_create ((const char *) propValue, pool);
 
-/*    const char *pname_utf8;
-    svn_utf_cstring_to_utf8 (&pname_utf8, propName, pool);*/
-
     svn_revnum_t revnum;
     svn_error_t * error = 
       svn_client_revprop_set (propName,
@@ -371,27 +383,24 @@ namespace svn
    * @return PropertiesList
    */
   svn_revnum_t
-  Client::revpropdel(const char *propName,
-                  const Path &path,
-                  const Revision &revision,
-                  bool force)
+  Client::revpropdel (const char *propName,
+                      const Path &path,
+                      const Revision &revision,
+                      bool force)
   {
     Pool pool;
 
-/*    const char *pname_utf8;
-    svn_utf_cstring_to_utf8 (&pname_utf8, propName, pool); */
-
     svn_revnum_t revnum;
     svn_error_t * error = 
-      error = svn_client_revprop_set (propName, 
-                                      NULL, // value = NULL
-                                      path.c_str (),
-                                      revision.revision (),
-                                      &revnum,
-                                      force,
-                                      *m_context,
-                                      pool);
-    if(error != NULL)
+      svn_client_revprop_set (propName, 
+                              NULL, // value = NULL
+                              path.c_str (),
+                              revision.revision (),
+                              &revnum,
+                              force,
+                              *m_context,
+                              pool);
+    if (error != NULL)
       throw ClientException (error);
 
     return revnum;
