@@ -1,9 +1,21 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2004 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
  *
- * This software is licensed as described in the file LICENSE.txt,
- * which you should have received as part of this distribution.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library (in the file LGPL.txt); if not, 
+ * write to the Free Software Foundation, Inc., 51 Franklin St, 
+ * Fifth Floor, Boston, MA  02110-1301  USA
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -11,6 +23,21 @@
  * ====================================================================
  */
 
+/**
+ * @todo implement 1.3 SVN api:
+ *
+ *  SVN_CLIENT_COMMIT_ITEM_LOCK_TOKEN
+ *  svn_client_add3
+ *  svn_client_copy2
+ *  svn_client_commit3
+ *  svn_client_delete2
+ *  svn_client_move3
+ *  svn_client_mkdir2
+ *  svn_client_import2
+ *  svn_client_info
+ */
+
+
 // Apache Portable Runtime
 #include "apr_xlate.h"
 
@@ -24,7 +51,7 @@
 #include "svncpp/apr.hpp"
 #include "svncpp/context.hpp"
 #include "svncpp/context_listener.hpp"
-
+#include "svncpp/check.hpp"
 
 namespace svn
 {
@@ -196,6 +223,11 @@ namespace svn
       ctx.notify_baton = this;
       ctx.cancel_func = onCancel;
       ctx.cancel_baton = this;
+
+#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 2)
+      ctx.notify_func2 = onNotify2;
+      ctx.notify_baton2 = this;
+#endif
     }
 
     void setAuthCache(bool value)
@@ -238,11 +270,11 @@ namespace svn
     static svn_error_t *
     onLogMsg (const char **log_msg, 
               const char **tmp_file,
-              apr_array_header_t *commit_items,
+              apr_array_header_t *, //UNUSED commit_items
               void *baton,
-              apr_pool_t *pool)
+              apr_pool_t * pool)
     {
-      Data * data;
+      Data * data = NULL;
       SVN_ERR (getData (baton, &data));
 
       std::string msg;
@@ -284,6 +316,31 @@ namespace svn
                     prop_state, revision);
     }
 
+
+#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 2)
+    /**
+     * this is the callback function for the subversion 1.2
+     * api functions to signal the progress of an action
+     * 
+     * @todo right now we forward only to @a onNotify,
+     *       but maybe we should a notify2 to the listener
+     * @since subversion 1.2
+     */
+    static void
+    onNotify2 (void*baton,const svn_wc_notify_t *action,apr_pool_t *)
+    {
+      if (!baton)
+        return;
+       
+      // for now forward the call to @a onNotify
+      onNotify (baton, action->path, action->action,
+                action->kind, action->mime_type,
+                action->content_state, action->prop_state,
+                action->revision);
+    }
+#endif
+
+
     /**
      * this is the callback function for the subversion
      * api functions to signal the progress of an action
@@ -296,7 +353,7 @@ namespace svn
 
       Data * data = static_cast <Data *> (baton);
 
-      if( data->cancel () )
+      if (data->cancel ())
         return svn_error_create (SVN_ERR_CANCELLED, NULL, "cancelled by user");
       else
         return SVN_NO_ERROR;
@@ -313,7 +370,7 @@ namespace svn
                     svn_boolean_t _may_save,
                     apr_pool_t *pool)
     {
-      Data * data;
+      Data * data = NULL;
       SVN_ERR (getData (baton, &data));
 
       bool may_save = _may_save != 0;
@@ -350,7 +407,7 @@ namespace svn
                             svn_boolean_t may_save,
                             apr_pool_t *pool)
     {
-      Data * data;
+      Data * data = NULL;
       SVN_ERR (getData (baton, &data));
       
       ContextListener::SslServerTrustData trustData (failures);
@@ -395,7 +452,7 @@ namespace svn
                            void *baton, 
                            apr_pool_t *pool)
     {
-      Data * data;
+      Data * data = NULL;
       SVN_ERR (getData (baton, &data));
 
       std::string certFile;
@@ -428,7 +485,7 @@ namespace svn
       svn_boolean_t maySave,
       apr_pool_t *pool)
     {
-      Data * data;
+      Data * data = NULL;
       SVN_ERR (getData (baton, &data));
 
       std::string password;
