@@ -1,9 +1,21 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2004 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
  *
- * This software is licensed as described in the file LICENSE.txt,
- * which you should have received as part of this distribution.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library (in the file LGPL.txt); if not, 
+ * write to the Free Software Foundation, Inc., 51 Franklin St, 
+ * Fifth Floor, Boston, MA  02110-1301  USA
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -13,6 +25,7 @@
 
 // stl
 #include <string>
+#include <sstream>
 
 // svncpp
 #include "svncpp/exception.hpp"
@@ -75,9 +88,23 @@ namespace svn
 
     m->apr_err = error->apr_err;
     svn_error_t * next = error->child;
+    /// @todo send rapidsvn an hint that error->message may sometimes NULL!
     std::string & message = m->message;
-    message = error->message;
-    while (next != 0)
+    if (error->message) 
+      message = error->message;
+    else 
+    {
+      message = "Unknown error!\n";
+      if (error->file) 
+      {
+        message += "In file ";
+        message += error->file;
+        std::stringstream num;
+        num << " Line " << error->line;
+        message += num.str();
+      }
+    }
+    while (next != NULL && next->message != NULL)
     {
       message = message + "\n" + next->message;
 
