@@ -119,11 +119,46 @@ namespace svn
     return m_pathIsUrl;
   }
 
+  static bool 
+  isAbsolute (const char * path)
+  {
+    if (0 == path)
+      return false;
+
+    std::string p (path);
+
+    if (0 == p.length ())
+      return false;
+
+    // a path that begins with "/" is absolute
+    if ('/' == p [0])
+      return true;
+
+    // a path with a ":" like "http://xxx" or
+    // "c:/foo" is absolute too
+    if (p.find (":", 0) != std::string::npos)
+      return true;
+
+    // Well it's relative
+    return false;
+  }
+
   void
   Path::addComponent (const char * component)
   {
     Pool pool;
 
+    if (0 == component)
+      return;
+
+    // if the @a component is absolute, simply
+    // use it
+    if (isAbsolute (component))
+    {
+      m_path = component;
+      return;
+    }
+
     if (Url::isValid (m_path.c_str ()))
     {
       const char * newPath =
@@ -346,7 +381,19 @@ end:
   {
     Pool pool;
 
-    return svn_path_local_style (m_path.c_str (), pool);
+    if (m_pathIsUrl)
+    {
+      // this converts something like
+      // http://foo/my%20location 
+      // to 
+      // http://foo/my location
+      return svn_path_uri_decode (m_path.c_str (), pool); 
+    }
+    else
+    {
+      // On Windows, p://foo/bar will be converted to p:\foo\bar
+      return svn_path_local_style (m_path.c_str (), pool);
+    }
   }
 }
 
