@@ -1,9 +1,21 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2004 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
  *
- * This software is licensed as described in the file LICENSE.txt,
- * which you should have received as part of this distribution.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library (in the file LGPL.txt); if not, 
+ * write to the Free Software Foundation, Inc., 51 Franklin St, 
+ * Fifth Floor, Boston, MA  02110-1301  USA
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -21,11 +33,10 @@
 #include "svncpp/pool.hpp"
 #include "svncpp/property.hpp"
 #include "svncpp/revision.hpp"
-
+#include "m_check.hpp"
 
 namespace svn
 {
-
   PropertyEntry::PropertyEntry (const char * name, const char * value)
   {
     this->name = name;
@@ -128,13 +139,41 @@ namespace svn
     return propval->data;
   }
 
+#if (CHECK_SVN_VERSION(1,2))
   void
   Property::set (const char * name, const char * value)
   {
     Pool pool;
 
-    const svn_string_t * propval 
-      = svn_string_create ((const char *) value, pool);
+    const svn_string_t * propval =
+      svn_string_create ((const char *) value, pool);
+
+//    const char *pname_utf8;
+  //  svn_utf_cstring_to_utf8 (&pname_utf8, name, pool);
+
+    bool recurse = false;
+    bool skip_checks = false;
+
+    svn_error_t * error = 
+      svn_client_propset2 (name,
+                           propval,
+                           m_path.c_str (),
+                           recurse,
+                           skip_checks,
+                           *m_context,
+                           pool);
+
+    if(error != NULL)
+      throw ClientException (error);
+  }
+#else
+  void
+  Property::set (const char * name, const char * value)
+  {
+    Pool pool;
+
+    const svn_string_t * propval =
+      svn_string_create ((const char *) value, pool);
 
 //    const char *pname_utf8;
   //  svn_utf_cstring_to_utf8 (&pname_utf8, name, pool);
@@ -145,6 +184,7 @@ namespace svn
     if(error != NULL)
       throw ClientException (error);
   }
+#endif
 
   void 
   Property::remove (const char * name)
@@ -155,11 +195,11 @@ namespace svn
   //  svn_utf_cstring_to_utf8 (&pname_utf8, name, pool);
 
     svn_error_t * error = 
-      error = svn_client_propset (name, 
-                                  NULL, // value = NULL
-                                  m_path.c_str (),
-                                  false, //dont recurse
-                                  pool);
+      svn_client_propset (name, 
+                          NULL, // value = NULL
+                          m_path.c_str (),
+                          false, //dont recurse
+                          pool);
     if(error != NULL)
       throw ClientException (error);
   }
