@@ -26,10 +26,6 @@
 #pragma warning( disable: 4786 )// debug symbol truncated
 #endif
 
-// stl
-#include <string>
-#include <vector>
-
 // subversion api
 #include "svn_path.h"
 
@@ -37,7 +33,6 @@
 #include "svncpp/pool.hpp"
 #include "svncpp/url.hpp"
 
-
 namespace svn
 {
   Url::Url () {}
@@ -59,7 +54,7 @@ namespace svn
   }
 
   /**
-   * returns a url with forbidden charachters like spaces escaped
+   * returns a url with forbidden characters like spaces escaped
    *
    * @param url url to be escaped
    *
@@ -73,6 +68,22 @@ namespace svn
     return svn_path_uri_autoescape (url, pool);
   }
 
+  /**
+   * returns a url with unescaped special characters, undo changes of the
+   * previous, escape function
+   *
+   * @param url url to be unescaped
+   *
+   * @return string unescaped url
+   */
+  std::string
+  Url::unescape (const char * url)
+  {
+    Pool pool;
+
+    return svn_path_uri_decode (url, pool);
+  }
+
   /**
    * the implementation of the function that pull the supported
    * url schemas out of the ra layer it rather dirty now since
