@@ -85,6 +85,7 @@ public:
    */
   virtual svn::Context * 
   GetContext () const;
+
 private:
   class Data;
   Data * m;
@@ -93,37 +94,6 @@ private:
    * disallow private copy constructor
    */
   ThreadedWorker (const ThreadedWorker &);
-
-  /**
-   * sends a message to the tracer. This is
-   * a utility function that checks m_tracer
-   * before tracing
-   *
-   * @param message to send
-   */
-  void Trace (const wxString & message);
-
-  /**
-   * Posts a string event. This is used the
-   * completion of an action or an error
-   * 
-   * @param code event code
-   * @param str string
-   * @param event_id
-   */
-  void
-  PostStringEvent (int code, wxString str, int event_id);
-
-  /**
-   * Posts a data event. This call is thread-safe
-   *
-   * @param code
-   * @param data
-   * @param event_id
-   */
-  void
-  PostDataEvent (int code, void * data, int event_id);
-
 };
 
 #endif
