@@ -1,9 +1,21 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2004 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
  *
- * This software is licensed as described in the file LICENSE.txt,
- * which you should have received as part of this distribution.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in the file GPL.txt); if not, write to 
+ * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Boston, MA  02110-1301  USA
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -379,11 +391,11 @@ close_edit (void *edit_baton, apr_pool_t *)
   if (!eb->no_final_line)
   {
     if (eb->is_checkout)
-      //printf( "Checked out revision %" SVN_REVNUM_T_FMT ".\n",
-      //  eb->revision );
     {
       wxString str =
-        wxString::Format (wxT("Checked out revision %" SVN_REVNUM_T_FMT "."),
+        wxString::Format (wxT("Checked out revision %")
+                          wxT(SVN_REVNUM_T_FMT)
+                          wxT("."),
                           eb->revision);
       eb->tracer->Trace (str);
     }
@@ -391,19 +403,19 @@ close_edit (void *edit_baton, apr_pool_t *)
     {
       if (eb->changed)
       {
-        //printf( "Updated to revision %" SVN_REVNUM_T_FMT ".\n",
-        //  eb->revision );
         wxString str =
-          wxString::Format (wxT("Updated to revision %" SVN_REVNUM_T_FMT "."),
+          wxString::Format (wxT("Updated to revision %")
+                            wxT(SVN_REVNUM_T_FMT)
+                            wxT("."),
                             eb->revision);
         eb->tracer->Trace (str);
       }
 
       else
       {
-        //printf( "At revision %" SVN_REVNUM_T_FMT ".\n",
-        //  eb->revision );
-        wxString str = wxString::Format (wxT("At revision %" SVN_REVNUM_T_FMT "."),
+        wxString str = wxString::Format (wxT("At revision %")
+                                         wxT(SVN_REVNUM_T_FMT)
+                                         wxT("."),
                                          eb->revision);
         eb->tracer->Trace (str);
       }
