@@ -29,6 +29,8 @@
 #include "wx/wx.h"
 #include "wx/datetime.h"
 #include "wx/filename.h"
+#include "wx/mstream.h"
+#include "wx/image.h"
 
 // apr
 #include "apr_strings.h"
@@ -47,16 +49,20 @@
 #include "verblist.hpp"
 
 // bitmaps
-#include "res/bitmaps/add.xpm"
-#include "res/bitmaps/commit.xpm"
-#include "res/bitmaps/delete.xpm"
-#include "res/bitmaps/info.xpm"
-#include "res/bitmaps/log.xpm"
-#include "res/bitmaps/resolve.xpm"
-#include "res/bitmaps/revert.xpm"
-#include "res/bitmaps/update.xpm"
-#include "res/bitmaps/add_wc_bookmark.xpm"
-#include "res/bitmaps/remove_bookmark.xpm"
+#include "res/bitmaps/add.png.h"
+#include "res/bitmaps/commit.png.h"
+#include "res/bitmaps/copy.png.h"
+#include "res/bitmaps/delete.png.h"
+#include "res/bitmaps/info.png.h"
+#include "res/bitmaps/log.png.h"
+#include "res/bitmaps/move.png.h"
+#include "res/bitmaps/refresh.png.h"
+#include "res/bitmaps/rename.png.h"
+#include "res/bitmaps/resolve.png.h"
+#include "res/bitmaps/revert.png.h"
+#include "res/bitmaps/stop.png.h"
+#include "res/bitmaps/update.png.h"
+#include "res/bitmaps/annotate.png.h"
 
 /** configuration options */
 
@@ -67,7 +73,7 @@
  * Set this option to "false" if you encounter this.
  * Default: true
  */
-static const bool UseBitmapMenus = false;
+static const bool UseBitmapMenus = true;
 
 static wxMenuItem *
 CreateMenuItem (
@@ -159,28 +165,31 @@ AppendModifyMenu (wxMenu * parentMenu)
   parentMenu->AppendSeparator ();
 
   AppendMenuItem (parentMenu, ID_Property, _("&Properties...\tCTRL-P"),
-                  wxBitmap (info_xpm));
+                  EMBEDDED_BITMAP(info_png));
 
   parentMenu->AppendSeparator ();
 
   AppendMenuItem (parentMenu, ID_Add, _("&Add\tCTRL-A"),
-                  wxBitmap (add_xpm));
+                  EMBEDDED_BITMAP(add_png));
   AppendMenuItem (parentMenu, ID_AddRecursive, _("Add r&ecursive"));
   AppendMenuItem (parentMenu, ID_Delete, _("&Delete\tDEL"),
-                  wxBitmap (delete_xpm));
+                  EMBEDDED_BITMAP(delete_png));
 
   parentMenu->AppendSeparator ();
 
   AppendMenuItem (parentMenu, ID_Revert, _("Re&vert\tCTRL-V"),
-                  wxBitmap (revert_xpm));
+                  EMBEDDED_BITMAP(revert_png));
   AppendMenuItem (parentMenu, ID_Resolve, _("Re&solve conflicts\tCTRL-S"),
-                  wxBitmap (resolve_xpm));
+                  EMBEDDED_BITMAP(resolve_png));
 
   parentMenu->AppendSeparator ();
 
-  AppendMenuItem (parentMenu, ID_Copy, _("&Copy...\tF5"));
-  AppendMenuItem (parentMenu, ID_Move, _("M&ove...\tF6"));
-  AppendMenuItem (parentMenu, ID_Rename, _("Re&name...\tCTRL-N"));
+  AppendMenuItem (parentMenu, ID_Copy, _("&Copy...\tF5"),
+                  EMBEDDED_BITMAP(copy_png));
+  AppendMenuItem (parentMenu, ID_Move, _("M&ove...\tF6"),
+                  EMBEDDED_BITMAP(move_png));
+  AppendMenuItem (parentMenu, ID_Rename, _("Re&name...\tCTRL-N"),
+                  EMBEDDED_BITMAP(rename_png));
   AppendMenuItem (parentMenu, ID_Mkdir, _("Make &directory...\tF7"));
 
   if (svn::SUPPORTS_LOCK)
@@ -200,9 +209,11 @@ AppendQueryMenu (wxMenu * parentMenu)
   AppendMenuItem (parentMenu, ID_DiffHead, _("&Diff to Head...\tCTRL+H"));
   parentMenu->AppendSeparator ();
   AppendMenuItem (parentMenu, ID_Log, _("&Log...\tCTRL-L"),
-                  wxBitmap (log_xpm));
+                  EMBEDDED_BITMAP(log_png));
   AppendMenuItem (parentMenu, ID_Info, _("&Info..."),
-                  wxBitmap (info_xpm));
+                  EMBEDDED_BITMAP(info_png));
+  AppendMenuItem (parentMenu, ID_Annotate, _("&Annotate..."),
+                  EMBEDDED_BITMAP(annotate_png));
 }
 
 void
@@ -238,7 +249,7 @@ AppendMenuItem (wxMenu & menu, int id)
 
   case ID_AddWcBookmark:
     caption = _("&Add Existing Working Copy...");
-    bitmap = wxBitmap (add_wc_bookmark_xpm);
+    // bitmap = EMBEDDED_BITMAP(add_wc_bookmark_png);
     break;
 
   case ID_AddRepoBookmark:
@@ -251,7 +262,7 @@ AppendMenuItem (wxMenu & menu, int id)
 
   case ID_RemoveBookmark:
     caption = _("&Remove Bookmark...");
-    bitmap = wxBitmap (remove_bookmark_xpm);
+    // bitmap = EMBEDDED_BITMAP(remove_bookmark_png);
     break;
 
   case ID_EditBookmark:
@@ -272,12 +283,12 @@ AppendMenuItem (wxMenu & menu, int id)
 
   case ID_Update:
     caption = _("&Update...\tCTRL-U");
-    bitmap = wxBitmap (update_xpm);
+    bitmap = EMBEDDED_BITMAP(update_png);
     break;
 
   case ID_Commit:
     caption = _("Co&mmit...\tCTRL-M");
-    bitmap = wxBitmap (commit_xpm);
+    bitmap = EMBEDDED_BITMAP(commit_png);
     break;
 
   case ID_Quit:
@@ -286,6 +297,7 @@ AppendMenuItem (wxMenu & menu, int id)
 
   case ID_Refresh:
     caption = _("Refresh View\tCTRL-R");
+    bitmap = EMBEDDED_BITMAP(refresh_png);
     break;
 
   case ID_Preferences:
@@ -302,13 +314,15 @@ AppendMenuItem (wxMenu & menu, int id)
 
   case ID_Stop:
     caption = _("&Stop");
+    bitmap = EMBEDDED_BITMAP(stop_png);
     break;
 
   case ID_Explore:
     caption = _("Explore...\tF2");
   }
-  wxMenuItem * item = AppendMenuItem (&menu, id, caption, bitmap);
 
+  wxMenuItem * item = AppendMenuItem (&menu, id, caption, bitmap);
+  
   return item;
 }
 
@@ -326,37 +340,6 @@ ParseRevision (const wxString & revstring, svn_revnum_t & revnum)
 }
 
 
-bool
-ParseDateTime (const wxString & datestring, apr_time_t & date)
-{
-  wxString value (datestring);
-
-  TrimString (value);
-
-  if (value.Length () <= 0)
-    return false;
-
-  // parse the string using the current locale setting
-  // (we check only if the complete parsing failed,
-  //  not if only the partial string could be parsed)
-  wxDateTime dateTime;
-  if (dateTime.ParseFormat (datestring, wxT("%c")) ==0)
-    return false;
-
-  apr_time_ansi_put (&date, dateTime.GetTicks ());
-  return true;
-}
-
-
-bool
-CheckDateTime (const wxString & datestring)
-{
-  apr_time_t time;
-
-  return ParseDateTime (datestring, time);
-}
-
-
 wxString
 FormatDateTime (apr_time_t date, wxString fmt)
 {
@@ -585,6 +568,41 @@ AppendVerbMenu (wxMenu * parentMenu, svn::Status * status)
     }
 }
 
+
+wxBitmap 
+EmbeddedBitmap (const unsigned char * data, size_t len)
+{
+  wxMemoryInputStream is (data, len);
+  wxImage img (is, wxBITMAP_TYPE_ANY, -1);
+  img.ConvertAlphaToMask ();
+  return wxBitmap (img, -1);
+}
+
+
+void
+OpenURL (const wxString & url)
+{
+#ifdef _WIN32
+  // Right now @ref wxLaunchDefaultBrowser works only on
+  // Windows, we have to work on this and detect
+  // the browser on Mac OS and Linux as well
+  wxLaunchDefaultBrowser (url);
+#else
+  // Well, maybe we can run Firefox?
+  wxString args;
+  args.Printf (wxT("firefox \"%s\""), url.c_str ());
+  wxExecute (args, wxEXEC_ASYNC | wxEXEC_NOHIDE);
+#endif
+}
+
+
+wxString
+PathToNative (const svn::Path & path)
+{
+  return Utf8ToLocal (path.native ());
+}
+
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
